@@ -10,6 +10,7 @@ from vnpy.trader.object import BarData, TickData
 from vnpy.trader.database import (
     BaseDatabase,
     BarOverview,
+    TickOverview,
     DB_TZ,
     convert_tz
 )
@@ -19,7 +20,8 @@ from .dolphindb_script import (
     CREATE_DATABASE_SCRIPT,
     CREATE_BAR_TABLE_SCRIPT,
     CREATE_TICK_TABLE_SCRIPT,
-    CREATE_OVERVIEW_TABLE_SCRIPT
+    CREATE_BAROVERVIEW_TABLE_SCRIPT,
+    CREATE_TICKOVERVIEW_TABLE_SCRIPT
 )
 
 
@@ -46,9 +48,10 @@ class DolphindbDatabase(BaseDatabase):
             self.session.run(CREATE_DATABASE_SCRIPT)
             self.session.run(CREATE_BAR_TABLE_SCRIPT)
             self.session.run(CREATE_TICK_TABLE_SCRIPT)
-            self.session.run(CREATE_OVERVIEW_TABLE_SCRIPT)
+            self.session.run(CREATE_BAROVERVIEW_TABLE_SCRIPT)
+            self.session.run(CREATE_TICKOVERVIEW_TABLE_SCRIPT)
 
-    def save_bar_data(self, bars: List[BarData]) -> bool:
+    def save_bar_data(self, bars: List[BarData], stream: bool = False) -> bool:
         """保存k线数据"""
         # 读取主键参数
         bar: BarData = bars[0]
@@ -84,37 +87,38 @@ class DolphindbDatabase(BaseDatabase):
         appender.append(df)
 
         # 计算已有K线数据的汇总
-        table = self.session.loadTable(tableName="bar", dbPath=self.db_path)
-
-        df_start: pd.DataFrame = (
-            table.select("*")
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
-            .where(f"interval=`{interval.value}")
-            .sort(bys=["datetime"]).top(1)
+        overview_table = self.session.loadTable(tableName="baroverview", dbPath=self.db_path)
+        overview: pd.DataFrame = (
+            overview_table.select('*')
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
+            .where(f'interval="{interval.value}"')
             .toDF()
         )
 
-        df_end: pd.DataFrame = (
-            table.select("*")
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
-            .where(f"interval=`{interval.value}")
-            .sort(bys=["datetime desc"]).top(1)
-            .toDF()
-        )
+        if overview.empty:
+            start: datetime = np.datetime64(bars[0].datetime)
+            end: datetime = np.datetime64(bars[-1].datetime)
+            count: int = len(bars)
+        elif stream:
+            start: datetime = overview["start"][0]
+            end: datetime = np.datetime64(bars[-1].datetime)
+            count: int = overview["count"][0] + len(bars)
+        else:
+            start: datetime = min(np.datetime64(bars[0].datetime), overview["start"][0])
+            end: datetime = max(np.datetime64(bars[-1].datetime), overview["end"][0])
 
-        df_count: pd.DataFrame = (
-            table.select("count(*)")
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
-            .where(f"interval=`{interval.value}")
-            .toDF()
-        )
+            bar_table = self.session.loadTable(tableName="bar", dbPath=self.db_path)
 
-        count: int = df_count["count"][0]
-        start: datetime = df_start["datetime"][0]
-        end: datetime = df_end["datetime"][0]
+            df_count: pd.DataFrame = (
+                bar_table.select('count(*)')
+                .where(f'symbol="{symbol}"')
+                .where(f'exchange="{exchange.value}"')
+                .where(f'interval="{interval.value}"')
+                .toDF()
+            )
+
+            count: int = df_count["count"][0]
 
         # 更新K线汇总数据
         data: List[dict] = []
@@ -134,13 +138,18 @@ class DolphindbDatabase(BaseDatabase):
 
         df: pd.DataFrame = pd.DataFrame.from_records(data)
 
-        appender = ddb.PartitionedTableAppender(self.db_path, "overview", "datetime", self.pool)
+        appender = ddb.PartitionedTableAppender(self.db_path, "baroverview", "datetime", self.pool)
         appender.append(df)
 
         return True
 
-    def save_tick_data(self, ticks: List[TickData]) -> bool:
+    def save_tick_data(self, ticks: List[TickData], stream: bool = False) -> bool:
         """保存TICK数据"""
+        # 读取主键参数
+        tick: BarData = ticks[0]
+        symbol: str = tick.symbol
+        exchange: Exchange = tick.exchange
+
         data: List[dict] = []
 
         for tick in ticks:
@@ -199,6 +208,58 @@ class DolphindbDatabase(BaseDatabase):
         appender = ddb.PartitionedTableAppender(self.db_path, "tick", "datetime", self.pool)
         appender.append(df)
 
+        # 计算已有Tick数据的汇总
+        overview_table = self.session.loadTable(tableName="tickoverview", dbPath=self.db_path)
+        overview: pd.DataFrame = (
+            overview_table.select('*')
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
+            .toDF()
+        )
+
+        if overview.empty:
+            start: datetime = np.datetime64(ticks[0].datetime)
+            end: datetime = np.datetime64(ticks[-1].datetime)
+            count: int = len(ticks)
+        elif stream:
+            start: datetime = overview["start"][0]
+            end: datetime = np.datetime64(ticks[-1].datetime)
+            count: int = overview["count"][0] + len(ticks)
+        else:
+            start: datetime = min(np.datetime64(ticks[0].datetime), overview["start"][0])
+            end: datetime = max(np.datetime64(ticks[-1].datetime), overview["end"][0])
+
+            bar_table = self.session.loadTable(tableName="tick", dbPath=self.db_path)
+
+            df_count: pd.DataFrame = (
+                bar_table.select('count(*)')
+                .where(f'symbol="{symbol}"')
+                .where(f'exchange="{exchange.value}"')
+                .toDF()
+            )
+
+            count: int = df_count["count"][0]
+
+        # 更新Tick汇总数据
+        data: List[dict] = []
+
+        dt = np.datetime64(datetime(2022, 1, 1))    # 该时间戳仅用于分区
+
+        d: Dict = {
+            "symbol": symbol,
+            "exchange": exchange.value,
+            "count": count,
+            "start": start,
+            "end": end,
+            "datetime": dt,
+        }
+        data.append(d)
+
+        df: pd.DataFrame = pd.DataFrame.from_records(data)
+
+        appender = ddb.PartitionedTableAppender(self.db_path, "tickoverview", "datetime", self.pool)
+        appender.append(df)
+
         return True
 
     def load_bar_data(
@@ -220,12 +281,12 @@ class DolphindbDatabase(BaseDatabase):
         table = self.session.loadTable(tableName="bar", dbPath=self.db_path)
 
         df: pd.DataFrame = (
-            table.select("*")
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
-            .where(f"interval=`{interval.value}")
-            .where(f"datetime>={start}")
-            .where(f"datetime<={end}")
+            table.select('*')
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
+            .where(f'interval="{interval.value}"')
+            .where(f'datetime>={start}')
+            .where(f'datetime<={end}')
             .toDF()
         )
 
@@ -233,7 +294,7 @@ class DolphindbDatabase(BaseDatabase):
             return []
 
         df.set_index("datetime", inplace=True)
-        df = df.tz_localize(DB_TZ)
+        df = df.tz_localize(DB_TZ.key)
 
         # 转换为BarData格式
         bars: List[BarData] = []
@@ -276,11 +337,11 @@ class DolphindbDatabase(BaseDatabase):
         table = self.session.loadTable(tableName="tick", dbPath=self.db_path)
 
         df: pd.DataFrame = (
-            table.select("*")
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
-            .where(f"datetime>={start}")
-            .where(f"datetime<={end}")
+            table.select('*')
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
+            .where(f'datetime>={start}')
+            .where(f'datetime<={end}')
             .toDF()
         )
 
@@ -288,7 +349,7 @@ class DolphindbDatabase(BaseDatabase):
             return []
 
         df.set_index("datetime", inplace=True)
-        df = df.tz_localize(DB_TZ)
+        df = df.tz_localize(DB_TZ.key)
 
         # 转换为TickData格式
         ticks: List[TickData] = []
@@ -349,10 +410,10 @@ class DolphindbDatabase(BaseDatabase):
 
         # 统计数据量
         df: pd.DataFrame = (
-            table.select("count(*)")
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
-            .where(f"interval=`{interval.value}")
+            table.select('count(*)')
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
+            .where(f'interval="{interval.value}"')
             .toDF()
         )
         count = df["count"][0]
@@ -360,19 +421,19 @@ class DolphindbDatabase(BaseDatabase):
         # 删除K线数据
         (
             table.delete()
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
-            .where(f"interval=`{interval.value}")
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
+            .where(f'interval="{interval.value}"')
             .execute()
         )
 
         # 删除K线汇总
-        table = self.session.loadTable(tableName="overview", dbPath=self.db_path)
+        table = self.session.loadTable(tableName="baroverview", dbPath=self.db_path)
         (
             table.delete()
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
-            .where(f"interval=`{interval.value}")
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
+            .where(f'interval="{interval.value}"')
             .execute()
         )
 
@@ -389,9 +450,9 @@ class DolphindbDatabase(BaseDatabase):
 
         # 统计数据量
         df: pd.DataFrame = (
-            table.select("count(*)")
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
+            table.select('count(*)')
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
             .toDF()
         )
         count: int = df["count"][0]
@@ -399,8 +460,17 @@ class DolphindbDatabase(BaseDatabase):
         # 删除Tick数据
         (
             table.delete()
-            .where(f"symbol=`{symbol}")
-            .where(f"exchange=`{exchange.value}")
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
+            .execute()
+        )
+
+        # 删除Tick汇总
+        table = self.session.loadTable(tableName="tickoverview", dbPath=self.db_path)
+        (
+            table.delete()
+            .where(f'symbol="{symbol}"')
+            .where(f'exchange="{exchange.value}"')
             .execute()
         )
 
@@ -408,8 +478,8 @@ class DolphindbDatabase(BaseDatabase):
 
     def get_bar_overview(self) -> List[BarOverview]:
         """"查询数据库中的K线汇总信息"""
-        table = self.session.loadTable(tableName="overview", dbPath=self.db_path)
-        df: pd.DataFrame = table.select("*").toDF()
+        table = self.session.loadTable(tableName="baroverview", dbPath=self.db_path)
+        df: pd.DataFrame = table.select('*').toDF()
 
         overviews: List[BarOverview] = []
 
@@ -425,3 +495,22 @@ class DolphindbDatabase(BaseDatabase):
             overviews.append(overview)
 
         return overviews
+
+    def get_tick_overview(self) -> List[TickOverview]:
+        """"查询数据库中的K线汇总信息"""
+        table = self.session.loadTable(tableName="tickoverview", dbPath=self.db_path)
+        df: pd.DataFrame = table.select('*').toDF()
+
+        overviews: List[TickOverview] = []
+
+        for tp in df.itertuples():
+            overview = TickOverview(
+                symbol=tp.symbol,
+                exchange=Exchange(tp.exchange),
+                count=tp.count,
+                start=datetime.fromtimestamp(tp.start.to_pydatetime().timestamp(), DB_TZ),
+                end=datetime.fromtimestamp(tp.end.to_pydatetime().timestamp(), DB_TZ),
+            )
+            overviews.append(overview)
+
+        return overviews
\ No newline at end of file
